#!/usr/bin/env python
# encoding=utf-8

import argparse
from kakashi.consts import *


# 命令行参数解析
parser = argparse.ArgumentParser(
    formatter_class=argparse.RawDescriptionHelpFormatter,
    prog=NAME,
    prefix_chars='-+',
    description=DESC,
)

# 一级参数
parser.add_argument('-d', '--debug', action='store_true', help='启用调试模式')
parser.add_argument('-v', '--verbose', action='store_true', help='显示详细日志')
parser.add_argument('-V', '--version', action='version', version=VERSION, help='查看当前版本号')
parser.add_argument('-f', '--from_path', help='准备分身的文件或目录的路径')
parser.add_argument('-t', '--to_path', help='文件或目录分身后保存的路径')
parser.add_argument('-m', '--map_path', help='分身时需要替换的内容映射文件路径，每一行为一条映射，每条映射的格式须为"旧文本 => 新文本"')
parser.add_argument('-r', '--remove_if_exist', action='store_true', help='若保存的路径已存在文件，则直接将其删除')

# 解析命令
args = parser.parse_args()



#!/usr/bin/env python
# encoding=utf-8

from kakashi.logger import *


class Kakashi:

    # 初始化
    def __init__(self):
        print_verbose()
        print_verbose(f'# Kakashi - File Doppelganger')
        print_verbose()

        if args.from_path is None or args.to_path is None:
            parser.print_help()
            parser.exit()

        if not os.path.exists(args.from_path):
            print_fatal(f'原路径不存在：{args.from_path}')

        if os.path.exists(args.to_path):
            if args.remove_if_exist or args.debug:
                os_system(f'rm -rf {args.to_path}')
            else:
                print_fatal(f'保存路径已存在，请先删除，或换个路径：{args.to_path}')

        print_verbose(f'## 解析映射')
        print_verbose()
        self.map = [(args.from_path, args.to_path)]
        if args.map_path is not None and os.path.isfile(args.map_path):
            with open(args.map_path, 'r') as rs:
                lines = rs.read().split('\n')
                for line in lines:
                    line_components = line.split('=>')
                    old = line_components[0].strip()
                    new = line_components[1].strip() if len(line_components) > 0 else ''
                    self.map.append((old, new))
        print_verbose(f'分身时需要替换的内容映射：')
        for old, new in self.map: print_verbose(f'{old} => {new}')
        print_verbose()

        print_verbose(f'## 开始分身')
        print_verbose()
        if os.path.isfile(args.from_path):
            self.doppelganger_file(args.from_path)
        else:
            self.doppelganger_dir(args.from_path)

        print_success()
        print_success(f'## 完成')
        print_success()
        print_success(f'已自动打开保存的目录...')
        os_system(f'open {args.to_path}')
        print_success()


    # 内容替换
    def doppelganger_str(self, from_string):
        to_string = from_string
        for old, new in self.map:
            to_string = to_string.replace(old, new)
        return to_string


    # 分身文件
    def doppelganger_file(self, from_file):
        to_file = self.doppelganger_str(from_file)
        print_success(f'📃 {from_file} ➡️  {to_file}')
        with open(from_file, 'r') as rs:
            content = rs.read()
            content = self.doppelganger_str(content)
            ws = open(to_file, 'w', encoding='utf8')
            ws.write(content)
            ws.close()


    # 分身目录
    def doppelganger_dir(self, from_dir):
        to_dir = self.doppelganger_str(from_dir)
        print_success(f'📂 {from_dir} ➡️  {to_dir}')
        os.makedirs(to_dir) if not os.path.exists(to_dir) else None

        for home, dirs, files in os.walk(from_dir):
            for file in files:
                if file == '.DS_Store': continue
                self.doppelganger_file(f'{home}/{file}')

            for dir in dirs:
                self.doppelganger_dir(f'{home}/{dir}')



#!/usr/bin/env python
# encoding=utf-8

import os
import time

# =========================================== COPYRIGHT ===========================================
NAME = 'kakashi'
SHORTCUT = 'kks'
DESC = '在保留原文件/目录结构的同时，批量替换指定文本，以快速创建文件分身'
VERSION = '0.1.0'
UPDATE_TIME = '2022/04/08'
AUTHOR_NAME = 'Andy Meng'
AUTHOR_EMAIL = 'andy_m129@163.com'
URL = 'https://github.com/AndyM129/FileDoppelganger'

# =========================================== GLOBAL CONST ===========================================
TIMESTAMP = int(time.time())  # 当前时间戳，eg. 1617351251
DATE_TIME = time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(TIMESTAMP))  # 当前时间，eg. 2021-04-02 16:14:11
DATE_STAMP = time.strftime('%Y%m%d%H%M%S', time.localtime(TIMESTAMP))  # 当前时间戳，eg. 20210402161411
FILE = __file__  # 当前文件路径
DIR = os.getcwd()  # 当前的文件目录
BASENAME = os.path.basename(FILE)  # 当前脚本的文件名
BASENAME_WITHOUT_SUFFIX = BASENAME.split('.')[0]  # 文件名（不含后缀）
BASENAME_SUFFIX = BASENAME.split('.')[1]  # 文件后缀



#!/usr/bin/env python
# encoding=utf-8

import sys
from colorama import *
from kakashi.arg_parse import *


# 时间
def debug_time():
    time_str = (time.strftime('%Y-%m-%d %H:%M:%S', time.localtime(time.time())))
    return f'[{time_str}] ' if args.debug else ''


# 输出信息：NOTSET
def print_noset(string='', end='\n'):
    print(debug_time() + string, end=end)


# 输出信息：DEBUG
def print_debug(string='', end='\n'):
    print(f'{Fore.LIGHTBLACK_EX}{Style.BRIGHT}{debug_time() + string}{Style.RESET_ALL}', end=end) if args.debug else None


# 输出信息：VERBOSE
def print_verbose(string='', end='\n'):
    print(f'{Fore.WHITE}{debug_time() + string}{Style.RESET_ALL}', end=end) if args.verbose else None


# 输出信息：INFO
def print_info(string='', end='\n'):
    print(f'{Fore.LIGHTCYAN_EX}{debug_time() + string}{Style.RESET_ALL}', end=end)


# 输出信息：WARNING
def print_warning(string='', end='\n'):
    print(f'{Fore.LIGHTYELLOW_EX}{debug_time() + string}{Style.RESET_ALL}', end=end)


# 输出信息：SUCCESS
def print_success(string='', end='\n'):
    print(f'{Fore.LIGHTGREEN_EX}{debug_time() + string}{Style.RESET_ALL}', end=end)


# 输出信息：ERROR
def print_error(string='', end='\n'):
    print(f'{Fore.LIGHTRED_EX}{debug_time() + string}{Style.RESET_ALL}', end=end)


# 输出信息：FATAL
def print_fatal(string='', end='\n', code=1):
    print(f'{Fore.LIGHTRED_EX}{debug_time() + Style.BRIGHT}{string}{Style.RESET_ALL}', end=end)
    if code is not None:
        sys.exit(code)


# 执行Shell 并打印命令、结果
def os_system(command, auto_exit=True):
    print_verbose()
    print_verbose(f'$ {command}')
    print_verbose()
    res = os.system(command)
    parser.exit() if res != 0 and auto_exit else None
    return res


# 输出信息：测试
def test_print():
    print_noset(f'[noset] This is {NAME}({VERSION})')
    print_debug(f'[debug] This is {NAME}({VERSION})')
    print_verbose(f'[verbose] This is {NAME}({VERSION})')
    print_info(f'[info] This is {NAME}({VERSION})')
    print_warning(f'[warning] This is {NAME}({VERSION})')
    print_success(f'[success] This is {NAME}({VERSION})')
    print_error(f'[error] This is {NAME}({VERSION})')
    print_fatal(f'[fatal] This is {NAME}({VERSION})')
    os_system(f'pwd')


# ========================================================= 打印内置常量 ============================================================
print_debug(f' Const '.center(120, '='))
print_debug(f'TIMESTAMP = {TIMESTAMP}')
print_debug(f'DATE_TIME = {DATE_TIME}')
print_debug(f'DATE_STAMP = {DATE_STAMP}')
print_debug(f'FILE = {FILE}')
print_debug(f'DIR = {DIR}')
print_debug(f'BASENAME = {BASENAME}')
print_debug(f'BASENAME_WITHOUT_SUFFIX = {BASENAME_WITHOUT_SUFFIX}')
print_debug(f'BASENAME_SUFFIX = {BASENAME_SUFFIX}')
print_debug()

# ========================================================= 打印命令行参数 ============================================================
print_debug(f' Command '.center(120, '='))
if args.debug is True: args.verbose = True
print_debug(f'$ {NAME} {" ".join(sys.argv[1:])}')
print_debug()

print_debug(f' Parsing Args '.center(120, '='))
for key, value in vars(parser.parse_args()).items():
    print_debug(f'{key} = {value}')
print_debug('\n' + '=' * 120 + '\n')
print_debug()



#!/usr/bin/env python
# encoding=utf-8

from kakashi.arg_parse import *
from kakashi.logger import *
from kakashi.kakashi import Kakashi


def main():
    Kakashi()


if __name__ == '__main__':
    main()



#!/usr/bin/env python
# coding: utf-8

import re


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup

with open("kakashi/consts.py", "r") as stream:
    content = stream.read()
    name = re.search(r'^NAME\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
    shortcut = re.search(r'^SHORTCUT\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1).replace(' ', '_').lower()
    version = re.search(r'^VERSION\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
    description = re.search(r'^DESC\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
    author = re.search(r'^AUTHOR_NAME\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
    author_email = re.search(r'^AUTHOR_EMAIL\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)
    url = re.search(r'^URL\s*=\s*[\'"]([^\'"]*)[\'"]', content, re.MULTILINE).group(1)

with open("README.md", "r") as stream:
    long_description = stream.read()

setup(
    name=f'amk_{name}',
    version=version,
    description=description,
    long_description_content_type="text/markdown",
    long_description=long_description,
    author=author,
    author_email=author_email,
    url=url,
    license='GNU General Public License v3.0',
    packages=[name],
    python_requires='>=3.9',
    install_requires=['colorama'],
    entry_points={
        'console_scripts': [
            f'{name}={name}:main',
            f'{shortcut}={name}:main',
        ]
    }
)
